DedicatedGpioFlex

Struct DedicatedGpioFlex 

pub struct DedicatedGpioFlex<'lt> { /* private fields */ }
A dedicated GPIO input and output driver.

On ESP32-S2 and ESP32-S3, the GPIO’s output is always enabled.

Note that the driver must only be used on the core that has created it. Do not send the driver to another core, either directly, or indirectly via a thread that is not pinned to a core.

Examples

use esp_hal::gpio::{
    Flex,
    Input,
    Level,
    dedicated::{DedicatedGpio, DedicatedGpioFlex},
};

// Create a pin driver:
let flex = Flex::new(peripherals.GPIO0);

// Create a dedicated GPIO driver:
let channels = DedicatedGpio::new(peripherals.GPIO_DEDICATED);
let mut dedicated_io = DedicatedGpioFlex::new(channels.channel0, flex);

// Now you can use the pin:
let level = dedicated_io.level();

Implementations

Source

impl<'lt> DedicatedGpioFlex<'lt>

pub fn new<CH, P>(channel: CH, pin: P) -> Self
where CH: InputChannel + OutputChannel + 'lt, P: InputDriver + OutputDriver + 'lt,

Creates a new dedicated GPIO input/output driver.

pub fn set_level(&mut self, level: Level)

Change the current state of the GPIO pin.

pub fn level(&self) -> Level

Read the current state of the GPIO pins.