DedicatedGpioInput

Struct DedicatedGpioInput 

pub struct DedicatedGpioInput<'lt> { /* private fields */ }
A dedicated GPIO input driver.

Note that the driver must only be used on the core that has created it. Do not send the driver to another core, either directly, or indirectly via a thread that is not pinned to a core.

Examples

use esp_hal::gpio::{
    Input,
    InputConfig,
    Level,
    dedicated::{DedicatedGpio, DedicatedGpioInput},
};

// Create an input pin driver:
let input = Input::new(peripherals.GPIO0, InputConfig::default());

// Create a dedicated GPIO driver:
let channels = DedicatedGpio::new(peripherals.GPIO_DEDICATED);
let mut dedicated_input = DedicatedGpioInput::new(channels.channel0, input);

// Now you can use the pin:
let level = dedicated_input.level();

Implementations

Source

impl<'lt> DedicatedGpioInput<'lt>

pub fn new<CH, P>(channel: CH, pin: P) -> Self
where CH: InputChannel + 'lt, P: InputDriver + 'lt,

Creates a new dedicated GPIO input driver.

pub fn level(&self) -> Level

Read the current state of the GPIO pins.